import subprocess
import requests
import argparse

def send_log(log_message, endpoint_url):
    try:
        response = requests.post(endpoint_url, data=log_message.encode("utf-8"), headers={"Content-Type": "text/plain"})
        if response.status_code == 200:
            print("Log sent successfully.")
        else:
            print(f"Failed to send log. Status code: {response.status_code}")
    except Exception as e:
        print(f"Error sending log: {e}")

def capture_logs(endpoint_url):
    subprocess.run(["adb", "logcat", "-c"])
    process = subprocess.Popen(
        ["adb", "logcat", "*:I", "*:D"], encoding="utf-8", errors="ignore",
        stdout=subprocess.PIPE,
        stderr=subprocess.PIPE,
        text=True
    )

    print("Listening for Android logs...")

    while True:
        log_line = process.stdout.readline().strip()
        if log_line and "Processing event:" in log_line:
            send_log(log_line, endpoint_url)

def main():
    parser = argparse.ArgumentParser(description="Track webengage android logs automatically and send them to webengage endpoint.")
    parser.add_argument("--webengage-android", required=True, help="Provide your endpoint url to send webengage logs data.")
    args = parser.parse_args()

    capture_logs(args.webengage_android)

if __name__ == "__main__":
    main()



from setuptools import setup, find_packages

setup(
    name="webengage-automation-app",
    version="0.1.1",
    packages=find_packages(),
    install_requires=["requests"],
    entry_points={
        "console_scripts": [
            "track=webengage_automation.logger:main",
        ],
    },
    author="Nipun Patel",
    author_email="nipunp27@gmail.com",
    description="Webengage internal tool to send the app logs to their API for testing the data with DataModel",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://www.webengage.com/",
    license="MIT",
    license_files=["LICEN[CS]E.*"], 
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6"
)
